@@ -1,12 +1,10 @@
 package BibTeX::Parser;
+our $VERSION = '0.3.2';
 
+# ABSTRACT: A pure perl BibTeX parser
 use warnings;
 use strict;
 
-our $VERSION = '0.3';
-
-use Text::Balanced qw(extract_bracketed extract_delimited);
-
 use BibTeX::Parser::Entry;
 
 =for stopwords jr von
@@ -17,7 +15,7 @@ BibTeX::Parser - A pure perl BibTeX parser
 
 =head1 VERSION
 
-version 0.3.1
+version 0.3.2
 
 =cut
 
@@ -47,8 +45,8 @@ Parses BibTeX files.
 		    my @editors = $entry->editor;
 		    
 		    foreach my $author (@authors) {
-			    print $author->first . " " 
-			    	. $author->von . " " 
+			    print $author->first . " "
+			    	. $author->von . " "
 				. $author->last . ", "
 				. $author->jr;
 		    }
@@ -239,7 +237,7 @@ sub _parse_string {
         {    # quoted string with embeded escapes
             $value .= $1;
         } else {
-            my $part = ( extract_bracketed( $_, "{}" ) )[0];
+            my $part = _extract_bracketed( $_ );
             $value .= substr $part, 1, length($part) - 2;    # strip quotes
         }
 
@@ -251,4 +249,23 @@ sub _parse_string {
     return $value;
 }
 
+sub _extract_bracketed
+{
+	for($_[0]) # alias to $_
+	{
+		/\G\s+/cg;
+		my $start = pos($_);
+		my $depth = 0;
+		while(1)
+		{
+			/\G\\./cg && next;
+			/\G\{/cg && (++$depth, next);
+			/\G\}/cg && (--$depth > 0 ? next : last);
+			/\G([^\\\{\}]+)/cg && next; 
+			last; # end of string
+		}
+		return substr($_, $start, pos($_)-$start);
+	}
+}
+
 1;    # End of BibTeX::Parser
\ No newline at end of file
